@@ -13,7 +13,7 @@ use Carp;
 use Errno;
 use Net::Cmd;
 
-our $VERSION = '3.11';
+our $VERSION = '3.14';
 
 $Net::FTP::IOCLASS or die "please load Net::FTP before Net::FTP::dataconn";
 our @ISA = $Net::FTP::IOCLASS;
@@ -137,6 +137,22 @@ __END__
 
 Net::FTP::dataconn - FTP Client data connection class
 
+=head1 SYNOPSIS
+
+    # Perform IO operations on an FTP client data connection object:
+
+    $num_bytes_read = $obj->read($buffer, $size);
+    $num_bytes_read = $obj->read($buffer, $size, $timeout);
+
+    $num_bytes_written = $obj->write($buffer, $size);
+    $num_bytes_written = $obj->write($buffer, $size, $timeout);
+
+    $num_bytes_read_so_far = $obj->bytes_read();
+
+    $obj->abort();
+
+    $closed_successfully = $obj->close();
+
 =head1 DESCRIPTION
 
 Some of the methods defined in C<Net::FTP> return an object which will
@@ -147,31 +163,31 @@ be performed using these.
 
 =over 4
 
-=item read ( BUFFER, SIZE [, TIMEOUT ] )
+=item C<read($buffer, $size[, $timeout])>
 
-Read C<SIZE> bytes of data from the server and place it into C<BUFFER>, also
-performing any <CRLF> translation necessary. C<TIMEOUT> is optional, if not
+Read C<$size> bytes of data from the server and place it into C<$buffer>, also
+performing any <CRLF> translation necessary. C<$timeout> is optional, if not
 given, the timeout value from the command connection will be used.
 
 Returns the number of bytes read before any <CRLF> translation.
 
-=item write ( BUFFER, SIZE [, TIMEOUT ] )
+=item C<write($buffer, $size[, $timeout])>
 
-Write C<SIZE> bytes of data from C<BUFFER> to the server, also
-performing any <CRLF> translation necessary. C<TIMEOUT> is optional, if not
+Write C<$size> bytes of data from C<$buffer> to the server, also
+performing any <CRLF> translation necessary. C<$timeout> is optional, if not
 given, the timeout value from the command connection will be used.
 
 Returns the number of bytes written before any <CRLF> translation.
 
-=item bytes_read ()
+=item C<bytes_read()>
 
 Returns the number of bytes read so far.
 
-=item abort ()
+=item C<abort()>
 
 Abort the current data transfer.
 
-=item close ()
+=item C<close()>
 
 Close the data connection and get a response from the FTP server. Returns
 I<true> if the connection was closed successfully and the first digit of
@@ -179,4 +195,43 @@ the response from the server was a '2'.
 
 =back
 
+=head1 EXPORTS
+
+I<None>.
+
+=head1 KNOWN BUGS
+
+I<None>.
+
+=head1 AUTHOR
+
+Graham Barr E<lt>L<gbarr@pobox.com|mailto:gbarr@pobox.com>E<gt>.
+
+Steve Hay E<lt>L<shay@cpan.org|mailto:shay@cpan.org>E<gt> is now maintaining
+libnet as of version 1.22_02.
+
+=head1 COPYRIGHT
+
+Copyright (C) 1997-2010 Graham Barr.  All rights reserved.
+
+Copyright (C) 2013-2014, 2020 Steve Hay.  All rights reserved.
+
+=head1 LICENCE
+
+This module is free software; you can redistribute it and/or modify it under the
+same terms as Perl itself, i.e. under the terms of either the GNU General Public
+License or the Artistic License, as specified in the F<LICENCE> file.
+
+=head1 VERSION
+
+Version 3.14
+
+=head1 DATE
+
+23 Dec 2020
+
+=head1 HISTORY
+
+See the F<Changes> file.
+
 =cut
