@@ -719,7 +719,7 @@ Perl_pad_alloc(pTHX_ I32 optype, U32 tmptype)
         pad_reset();
     if (tmptype == SVs_PADMY) { /* Not & because this ‘flag’ is 0.  */
         /* For a my, simply push a null SV onto the end of PL_comppad. */
-        sv = *av_store_simple(PL_comppad, AvFILLp(PL_comppad) + 1, newSV(0));
+        sv = *av_store_simple(PL_comppad, AvFILLp(PL_comppad) + 1, newSV_type(SVt_NULL));
         retval = (PADOFFSET)AvFILLp(PL_comppad);
     }
     else {
@@ -1025,26 +1025,6 @@ Perl_pad_findmy_sv(pTHX_ SV *name, U32 flags)
     return pad_findmy_pvn(namepv, namelen, flags);
 }
 
-/*
-=for apidoc find_rundefsvoffset
-
-Until the lexical C<$_> feature was removed, this function would
-find the position of the lexical C<$_> in the pad of the
-currently-executing function and return the offset in the current pad,
-or C<NOT_IN_PAD>.
-
-Now it always returns C<NOT_IN_PAD>.
-
-=cut
-*/
-
-PADOFFSET
-Perl_find_rundefsvoffset(pTHX)
-{
-    PERL_UNUSED_CONTEXT; /* Can we just remove the pTHX from the sig? */
-    return NOT_IN_PAD;
-}
-
 /*
 =for apidoc find_rundefsv
 
@@ -1110,7 +1090,7 @@ S_pad_findlex(pTHX_ const char *namepv, STRLEN namelen, U32 flags, const CV* cv,
     SV *new_capture;
     SV **new_capturep;
     const PADLIST * const padlist = CvPADLIST(cv);
-    const bool staleok = !!(flags & padadd_STALEOK);
+    const bool staleok = cBOOL(flags & padadd_STALEOK);
 
     PERL_ARGS_ASSERT_PAD_FINDLEX;
 
@@ -1252,13 +1232,13 @@ S_pad_findlex(pTHX_ const char *namepv, STRLEN namelen, U32 flags, const CV* cv,
                 }
                 if (!*out_capture) {
                     if (namelen != 0 && *namepv == '@')
-                        *out_capture = sv_2mortal(MUTABLE_SV(newAV()));
+                        *out_capture = newSV_type_mortal(SVt_PVAV);
                     else if (namelen != 0 && *namepv == '%')
-                        *out_capture = sv_2mortal(MUTABLE_SV(newHV()));
+                        *out_capture = newSV_type_mortal(SVt_PVHV);
                     else if (namelen != 0 && *namepv == '&')
-                        *out_capture = sv_2mortal(newSV_type(SVt_PVCV));
+                        *out_capture = newSV_type_mortal(SVt_PVCV);
                     else
-                        *out_capture = sv_newmortal();
+                        *out_capture = newSV_type_mortal(SVt_NULL);
                 }
             }
 
@@ -1565,7 +1545,7 @@ Perl_pad_swipe(pTHX_ PADOFFSET po, bool refadjust)
     /* if pad tmps aren't shared between ops, then there's no need to
      * create a new tmp when an existing op is freed */
 #ifdef USE_PAD_RESET
-    PL_curpad[po] = newSV(0);
+    PL_curpad[po] = newSV_type(SVt_NULL);
     SvPADTMP_on(PL_curpad[po]);
 #else
     PL_curpad[po] = NULL;
@@ -1858,7 +1838,6 @@ STATIC void
 S_cv_dump(pTHX_ const CV *cv, const char *title)
 {
     const CV * const outside = CvOUTSIDE(cv);
-    PADLIST* const padlist = CvPADLIST(cv);
 
     PERL_ARGS_ASSERT_CV_DUMP;
 
@@ -1878,9 +1857,15 @@ S_cv_dump(pTHX_ const CV *cv, const char *title)
                    : CvUNIQUE(outside) ? "UNIQUE"
                    : CvGV(outside) ? GvNAME(CvGV(outside)) : "UNDEFINED"));
 
-    PerlIO_printf(Perl_debug_log,
+    if (!CvISXSUB(cv)) {
+        /* SVPADLIST(cv) will fail an assert if CvISXSUB(cv) is true,
+         * and if the assert is removed this code will SEGV. XSUBs don't
+         * have padlists I believe - Yves */
+        PADLIST* const padlist = CvPADLIST(cv);
+        PerlIO_printf(Perl_debug_log,
                     "    PADLIST = 0x%" UVxf "\n", PTR2UV(padlist));
-    do_dump_pad(1, Perl_debug_log, padlist, 1);
+        do_dump_pad(1, Perl_debug_log, padlist, 1);
+    }
 }
 
 #endif /* DEBUGGING */
@@ -2030,7 +2015,7 @@ S_cv_clone_pad(pTHX_ CV *proto, CV *cv, CV *outside, HV *cloned,
                 else if (sigil == '%')
                     sv = MUTABLE_SV(newHV());
                 else
-                    sv = newSV(0);
+                    sv = newSV_type(SVt_NULL);
                 /* reset the 'assign only once' flag on each state var */
                 if (sigil != '&' && SvPAD_STATE(namesv))
                     SvPADSTALE_on(sv);
@@ -2041,7 +2026,7 @@ S_cv_clone_pad(pTHX_ CV *proto, CV *cv, CV *outside, HV *cloned,
             sv = SvREFCNT_inc_NN(ppad[ix]);
         }
         else {
-            sv = newSV(0);
+            sv = newSV_type(SVt_NULL);
             SvPADTMP_on(sv);
         }
         PL_curpad[ix] = sv;
@@ -2063,7 +2048,7 @@ S_cv_clone_pad(pTHX_ CV *proto, CV *cv, CV *outside, HV *cloned,
              */
             bool cloned_in_this_pass;
             if (!cloned)
-                cloned = (HV *)sv_2mortal((SV *)newHV());
+                cloned = (HV *)newSV_type_mortal(SVt_PVHV);
             do {
                 cloned_in_this_pass = FALSE;
                 for (ix = fpad; ix > 0; ix--) {
@@ -2435,7 +2420,7 @@ Perl_pad_push(pTHX_ PADLIST *padlist, int depth)
                     else if (sigil == '%')
                         sv = MUTABLE_SV(newHV());
                     else
-                        sv = newSV(0);
+                        sv = newSV_type(SVt_NULL);
                 }
             }
             else if (PadnamePV(names[ix])) {
@@ -2443,7 +2428,7 @@ Perl_pad_push(pTHX_ PADLIST *padlist, int depth)
             }
             else {
                 /* save temporaries on recursion? */
-                sv = newSV(0);
+                sv = newSV_type(SVt_NULL);
                 SvPADTMP_on(sv);
             }
             AvARRAY(newpad)[ix] = sv;
@@ -2543,7 +2528,7 @@ Perl_padlist_dup(pTHX_ PADLIST *srcpad, CLONE_PARAMS *param)
                             else if (sigil == '%')
                                 sv = MUTABLE_SV(newHV());
                             else
-                                sv = newSV(0);
+                                sv = newSV_type(SVt_NULL);
                             pad1a[ix] = sv;
                         }
                     }
@@ -2554,7 +2539,7 @@ Perl_padlist_dup(pTHX_ PADLIST *srcpad, CLONE_PARAMS *param)
                 }
                 else {
                     /* save temporaries on recursion? */
-                    SV * const sv = newSV(0);
+                    SV * const sv = newSV_type(SVt_NULL);
                     pad1a[ix] = sv;
 
                     /* SvREFCNT(oldpad[ix]) != 1 for some code in threads.xs
