@@ -6,8 +6,8 @@ afs='false'
 afsroot='/afs'
 alignbytes='4'
 aphostname='/bin/hostname'
-archlib='/usr/local/lib/perl5/5.35/unknown'
-archlibexp='/usr/local/lib/perl5/5.35/unknown'
+archlib='/usr/local/lib/perl5/5.37/unknown'
+archlibexp='/usr/local/lib/perl5/5.37/unknown'
 archname='unknown'
 asctime_r_proto='0'
 bin='/usr/local/bin'
@@ -63,6 +63,7 @@ d_attribute_nonnull='undef'
 d_attribute_noreturn='undef'
 d_attribute_pure='undef'
 d_attribute_unused='undef'
+d_attribute_visibility='undef'
 d_attribute_warn_unused_result='undef'
 d_backtrace='undef'
 d_bsd='undef'
@@ -429,6 +430,7 @@ d_semget='undef'
 d_semop='undef'
 d_sendmsg='undef'
 d_setegid='undef'
+d_setenv='undef'
 d_seteuid='undef'
 d_setgrent='undef'
 d_setgrent_r='undef'
@@ -789,8 +791,8 @@ perl_static_inline='static'
 perl_thread_local=''
 phostname='hostname'
 pidtype=int
-privlib='/usr/local/lib/perl5/5.35'
-privlibexp='/usr/local/lib/perl5/5.35'
+privlib='/usr/local/lib/perl5/5.37'
+privlibexp='/usr/local/lib/perl5/5.37'
 procselfexe=''
 prototype='undef'
 ptrsize='4'
@@ -840,11 +842,11 @@ sig_name_init='0'
 sig_num_init='0'
 sig_size='1'
 signal_t=int
-sitearch='/usr/local/lib/perl5/5.35/unknown'
-sitearchexp='/usr/local/lib/perl5/5.35/unknown'
-sitelib='/usr/local/lib/perl5/5.35'
+sitearch='/usr/local/lib/perl5/5.37/unknown'
+sitearchexp='/usr/local/lib/perl5/5.37/unknown'
+sitelib='/usr/local/lib/perl5/5.37'
 sitelib_stem='/usr/local/lib/perl5'
-sitelibexp='/usr/local/lib/perl5/5.35'
+sitelibexp='/usr/local/lib/perl5/5.37'
 sizesize=4
 sizetype='size_t'
 socksizetype='int'
@@ -865,7 +867,6 @@ stdio_filbuf=''
 stdio_ptr='((fp)->_IO_read_ptr)'
 stdio_stream_array=''
 strerror_r_proto='0'
-taint_support='define'
 targetarch=''
 targetsh='/bin/sh'
 timetype=time_t
