@@ -63,6 +63,7 @@ d_attribute_nonnull='undef'
 d_attribute_noreturn='undef'
 d_attribute_pure='undef'
 d_attribute_unused='undef'
+d_attribute_visibility='undef'
 d_attribute_warn_unused_result='undef'
 d_backtrace='undef'
 d_bsd='undef'
@@ -429,6 +430,7 @@ d_semget='undef'
 d_semop='undef'
 d_sendmsg='undef'
 d_setegid='undef'
+d_setenv='undef'
 d_seteuid='undef'
 d_setgrent='undef'
 d_setgrent_r='undef'
